@@ -33,19 +33,13 @@ class Feed2Twitter(object):
         self.items = items
         self.username = username
         self.passwd = passwd
-        from pkg_resources import resource_string
-        self.version = resource_string(__name__, '../VERSION')
+        self.version = __version__
         self.twApi = twitter.Api(username=self.username, password=self.passwd)
-        self.twApi.SetXTwitterHeaders('feed2twitter', 'http://www. assembla.com/spaces/feed2twitter', self.version)
-#        self.twApi.parameters['source'] = 'feed2twitter'
-#        self.twApi._request_headers['source'] = 'feed2twitter'
         self.set_attr_headers()
         self.rss = readrss.parse(url)
     
     def set_attr_headers(self):
-        return
-        self.api.SetUserAgent('"feed2twitter/0.2"')
-    
+        self.twApi.SetXTwitterHeaders('feed2twitter', 'http://www. assembla.com/spaces/feed2twitter', self.version)    
 
     def strip_tags(self,value):
         "Return the given HTML with all tags stripped."
@@ -151,3 +145,6 @@ def update():
             setattr(twitter.Api, PostUpdate.__name__, PostUpdate)
         feed2tw.update()
         time.sleep(interval)
+
+__version__ = '0.6.4'
+
